@@ -22,14 +22,20 @@
 #include "parse.h"
 #include "crc.h"
 
+/*
+static int createlisten(int port);
+static void closeconnection(int sockfd);
+*/
+static int createconnection_tcp(char *host, int port);
+
 extern int errno;
-char *opennet_urls[256];
+static char *opennet_urls[256];
 
 /*
  *	Create a listening port on tcp port PORT
  */
-int createlisten(int port)
-{
+/*
+static int createlisten(int port) {
 	struct sockaddr_in localname;
 	int sockFd;
 	sockFd=socket(AF_INET,SOCK_STREAM,IPPROTO_IP);
@@ -40,17 +46,20 @@ int createlisten(int port)
 	if (listen(sockFd,1024)==-1) { perror("listen"); return(-1); }
 	return(sockFd);
 }
+*/
 
 
 /*
  *	Close that socket, yeah.
  */
-void closeconnection(int sockfd) {
+/*
+static void closeconnection(int sockfd) {
 	shutdown(sockfd, 1);
 	close(sockfd);
 }
+*/
 
-int createconnection_tcp(char *host, int port) {
+static int createconnection_tcp(char *host, int port) {
 	int sockid;
 	struct hostent *hostinfo;
 	struct sockaddr_in sock;
@@ -283,10 +292,24 @@ off_t lseek_net(int filedes, off_t offset, int whence) {
 	return(lseek(filedes,offset,whence));
 }
 
+ssize_t read_net(int fd, void *buf, size_t count) {
+	ssize_t i=0,x;
+
+	while (i!=count) {
+		x=read(fd,(void *) ((buf)+i),count-i);
+		if (x==0) break;
+		if (x==-1) return(-1);
+		i+=x;
+	}
+
+	return(i);
+}
+
+
 #else
-int createlisten(int port) { return(-1); }
-void closeconnection(int sockfd) { return; }
-int createconnection_tcp(char *host, int port) { return(-1); }
+static int createlisten(int port) { return(-1); }
+static void closeconnection(int sockfd) { return; }
+static int createconnection_tcp(char *host, int port) { return(-1); }
 int open_net(const char *pathname, int flags,...) {
 	va_list args;
 	mode_t mode;
@@ -300,4 +323,7 @@ int open_net(const char *pathname, int flags,...) {
 off_t lseek_net(int filedes, off_t offset, int whence) {
 	return(lseek(filedes,offset,whence));
 }
+ssize_t read_net(int fd, void *buf, size_t count) {
+	return(read(fd, buf, count));
+}
 #endif
